@@ -4,6 +4,7 @@ from pyspark.sql.types import StructType
 from typing import Any, List
 
 import logging
+import re
 
 
 class DatabricksSpark:
@@ -74,6 +75,17 @@ class DatabricksSpark:
         except Exception as e:
             logging.error(f"Error: {e}")
 
+    @staticmethod
+    def rename_invalid_columns(*, data_frame: DataFrame) -> DataFrame:
+        try:
+            invalid_characters = "[ ,;{}()\n\t=\\/']"
+            for column in data_frame.columns:
+                column_replace = re.sub(invalid_characters, "_", column)
+                data_frame = data_frame.withColumnRenamed(column, column_replace)
+            return data_frame
+        except Exception as e:
+            logging.error(f"Error: {e}")
+
     @staticmethod
     def set_catalog(
         *,
